# Test Coverage Report

Generated: Tue 2014-07-15 16:34 CEST

| Statements
--- | ---
Module | total | executed | excluded | % covered
Total | 287 | 261 | 26 | 100.0%
user_media.__init__ | 1 | 1 | 0 | 100.0%
user_media.forms | 51 | 47 | 4 | 100.0%
user_media.models | 38 | 31 | 7 | 100.0%
user_media.processors | 4 | 4 | 0 | 100.0%
user_media.views | 193 | 178 | 15 | 100.0%

Excluded packages and modules
Error packages and modules